@@ -1,6 +1,6 @@
 
 /*
- * $Id: store.c,v 1.464.2.1 1998/10/01 21:18:10 wessels Exp $
+ * $Id: store.c,v 1.469.2.2 1998/11/13 17:43:54 wessels Exp $
  *
  * DEBUG: section 20    Storage Manager
  * AUTHOR: Harvest Derived
@@ -227,7 +227,6 @@ storeReleaseRequest(StoreEntry * e)
 {
     if (EBIT_TEST(e->flags, RELEASE_REQUEST))
 	return;
-    assert(storeEntryLocked(e));
     debug(20, 3) ("storeReleaseRequest: '%s'\n", storeKeyText(e->key));
     EBIT_SET(e->flags, RELEASE_REQUEST);
     /*
@@ -282,15 +281,7 @@ storeGet(const cache_key * key)
 StoreEntry *
 storeGetPublic(const char *uri, const method_t method)
 {
-    const cache_key *key;
-    StoreEntry *e;
-    key = storeKeyPublic(uri, method);
-    e = storeGet(key);
-    if (e == NULL && squid_curtime < 909000000) {
-	key = storeKeyPublicOld(uri, method);
-	e = storeGet(key);
-    }
-    return storeGet(key);
+    return storeGet(storeKeyPublic(uri, method));
 }
 
 static int
@@ -340,6 +331,9 @@ storeSetPublicKey(StoreEntry * e)
      * the object.  If we're not swapping out, then subsequent
      * store clients won't be able to access object data which has
      * been freed from memory.
+     *
+     * If RELEASE_REQUEST is set, then ENTRY_CACHABLE should not
+     * be set, and storeSetPublicKey() should not be called.
      */
     assert(!EBIT_TEST(e->flags, RELEASE_REQUEST));
     newkey = storeKeyPublic(mem->url, mem->method);
@@ -784,8 +778,7 @@ storeRelease(StoreEntry * e)
 	debug(20, 2) ("storeRelease: Delaying release until store is rebuilt: '%s'\n",
 	    storeUrl(e));
 	storeExpireNow(e);
-	storeSetPrivateKey(e);
-	EBIT_SET(e->flags, RELEASE_REQUEST);
+	storeReleaseRequest(e);
 	return;
     }
 #if USE_ASYNC_IO
@@ -863,7 +856,7 @@ storeEntryValidLength(const StoreEntry * e)
 	return 1;
     debug(20, 3) ("storeEntryValidLength: %d bytes too %s; '%s'\n",
 	diff < 0 ? -diff : diff,
-	diff < 0 ? "small" : "big",
+	diff < 0 ? "big" : "small",
 	storeKeyText(e->key));
     return 0;
 }
@@ -1006,8 +999,10 @@ storeFreeMemory(void)
     hashFreeItems(store_table, destroy_StoreEntry);
     hashFreeMemory(store_table);
     store_table = NULL;
+#if USE_CACHE_DIGEST
     if (store_digest)
 	cacheDigestDestroy(store_digest);
+#endif
     store_digest = NULL;
 }
 
